##  Step 2. Scope ERP Transformation
In this step, you will define the scope of your ERP transformation in close alignment with the business. For this, you will start with the business architecture layer in SAP LeanIX to ensure that all your decisions are business-driven and support your organization’s strategy. This helps you to get a first view of your target architecture and plan your transformation in the next steps.
In this step, you will:
  * Define what Business Capabilities (mapped to your Objectives) are impacted by the ERP transformation.
  * Explore how the rest of your Inventory is affected by the transformation, for example, what Applications or Organizations are related to the Business Capabilities in scope, and which Interfaces need to be considered.


**Note**
Refer to the [Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD) documentation in SAP LeanIX for detailed information on helpful reports. Additionally, refer to the [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") and [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.") use case guides for insights on building these reports and to make the most out of it.
The scoping activity should happen in close alignment with your business, with clear ownership of the Business Capabilities by business owners who understand what Business Capabilities mean. As an EA leading this effort, you would facilitate those discussions, e.g., as part of scoping workshops.
The SAP LeanIX best-practice approach for scoping consists of the following three steps:
  1. Leverage Gartner’s [Pace Layering](https://help.sap.com/docs/leanix/ea/pace-layering?locale=en-US&state=PRODUCTION&version=CLOUD) methodology to understand the strategic relevance of your Business Capabilities and derive decisions to build your target architecture. The three Pacer Layers (commodity, innovation, differentiation) facilitate conversations around the following questions:
    1. Commodity: Where in my application landscape do I want to leverage standards? For example, if you are driving an SAP transformation, this is where you would leverage standard capabilities from the SAP reference architecture.
    2. Innovation: Where do I want to be innovative and build custom applications?
    3. Differentiation: Which areas are relevant for my business and differentiate us from our competitors?
  2. Define a tag group called “ERP Transformation scope” with four values: Pain Point, In scope, Opportunity, To be decided (later), Out of Scope (non-ERP-related), and strong support already. For information on tags, refer [Tagging](https://help.sap.com/docs/leanix/ea/tags?locale=en-US&state=PRODUCTION&version=CLOUD "Tags are labels used to classify and categorize fact sheets, making it easy to filter, organize, and analyze data. Learn how to assign and manage tags, understand when and when not to use them, as well as leverage them for filtering and reporting.").
  3. Have conversations with the business, and assign tags to your Business Capabilities. You can leverage the [Bulk Updating Data in Inventory Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD "Table View lets you view and edit multiple fact sheets in a spreadsheet-like format—perfect for scanning, comparing, and updating data quickly and efficiently.") to drive informed decision-making in your discussions and document the results. As an outcome, all Business Capabilities should have a tag.
